@@ -503,7 +503,7 @@ class Application():
 
         prefsMenu.append(searchInSummaryMenuItem)
         prefsMenu.append(searchInDescriptionMenuItem)
-        prefsMenu.append(openLinkExternalMenuItem)
+        # prefsMenu.append(openLinkExternalMenuItem)
         prefsMenu.append(searchWhileTypingMenuItem)
 
         #prefsMenuItem.connect("activate", open_preferences, treeview_update, statusIcon, wTree)
@@ -622,6 +622,8 @@ class Application():
         wTree.get_widget("label_transactions_header").set_text(_("Active tasks:"))
         wTree.get_widget("progressbar1").hide_all()
 
+        wTree.get_widget("show_all_results_button").set_label(_("Show all results"))
+
         wTree.get_widget("button_transactions").connect("clicked", self.show_transactions)
         
         wTree.get_widget("tree_applications_scrolledview").get_vadjustment().connect("value-changed", self._on_tree_applications_scrolled, self.tree_applications)
@@ -975,7 +977,7 @@ class Application():
         self.show_category(self.root_category)
 
     @print_timing
-    def _on_package_load_finished(self, view, frame, package):        
+    def _on_package_load_finished(self, view, frame, package):             
         #Add the reviews
         reviews = package.reviews
         self.packageBrowser.execute_script('clearReviews()')
@@ -1039,6 +1041,7 @@ class Application():
         package = self.current_package
         if package is not None:
             if self.prefs['external_browser']:
+                clem
                 os.system("xdg-open " + self.current_package.pkg.candidate.homepage + " &")
             else:
                 self.websiteBrowser.open(self.current_package.pkg.candidate.homepage)
@@ -1526,9 +1529,17 @@ class Application():
             if package.pkg.is_installed:
                 im=Image.open(icon_path)
                 bg_w,bg_h=im.size
+                # The code that pastes the green checkmark icon expects a 32x32
+                # icon. Most icons are 32x32, however in some rare instances
+                # the icon might be e.g. 64x64.
+                im = im.resize((32, 32))
                 im2=Image.open("/usr/lib/linuxmint/mintInstall/data/emblem-installed.png")
                 img_w,img_h=im2.size 
                 offset=(17,17)         
+                # For the green checkmark pasting to work well, the original icon image
+                # must be in the same format as the green checkmark. Otherwise the checkmark
+                # might be loose some colour precision.
+                im = im.convert(im2.mode)
                 im.paste(im2, offset,im2)
                 tmpFile = tempfile.NamedTemporaryFile(delete=False)
                 im.save (tmpFile.name + ".png")             
@@ -1648,7 +1659,7 @@ class Application():
         del model_applications
         if self._search_in_category != self.root_category:
             self.search_in_category_hbox.show()
-            self.message_search_in_category_label.set_markup("<b>%s</b>" % (_("Only results in category \"%s\" are shown." % self._search_in_category.name)))
+            self.message_search_in_category_label.set_markup("<b>%s</b>" % (_("Only results in category \"%s\" are shown.") % self._search_in_category.name))
         if self._search_in_category == self.root_category:
             self.search_in_category_hbox.hide()
             self.navigation_bar.add_with_id(self._search_in_category.name, self.navigate, self.NAVIGATION_HOME, self._search_in_category)
@@ -1719,7 +1730,11 @@ class Application():
         subs['label_submit'] = _("Submit")
         subs['label_your_review'] = _("Your review")
 
-        impacted_packages = []    
+        impacted_packages = []  
+        js_removals = []
+        removals = []
+        installations = []
+
         pkg = self.cache[package.name]
         try:
             if package.pkg.is_installed:
@@ -1732,10 +1747,15 @@ class Application():
     
         changes = self.cache.get_changes()
         for pkg in changes:
-            if (pkg.is_installed):
-                impacted_packages.append(_("%s (removed)") % pkg.name)
-            else:
-                impacted_packages.append(_("%s (installed)") % pkg.name)
+            if pkg.name == package.name:
+                continue
+            if (pkg.is_installed):                
+                js_removals.append("'%s'" % pkg.name)
+                removals.append(pkg.name)
+            else:                
+                installations.append(pkg.name)
+
+        subs['removals'] = ", ".join(js_removals)
         
         downloadSize = str(self.cache.required_download) + _("B")
         if (self.cache.required_download >= 1000):
@@ -1757,11 +1777,14 @@ class Application():
             localSize = str(required_space / 1000000000) + _("GB")
 
         subs['sizeLabel'] = _("Size:")
-        subs['versionLabel'] = _("Version:")
-        subs['impactLabel'] = _("Impact on packages:")
+        subs['versionLabel'] = _("Version:")        
         subs['reviewsLabel'] = _("Reviews")
         subs['yourReviewLabel'] = _("Your review:")
         subs['detailsLabel'] = _("Details")
+
+        subs['warning_label'] = _("This will remove the following packages:")
+        subs['warning_cancel'] = _("Cancel")
+        subs['warning_confirm'] = _("Confirm")        
         
         if package.pkg.is_installed:
             if self.cache.required_space < 0:
@@ -1773,15 +1796,23 @@ class Application():
                 subs['sizeinfo'] = _("%(downloadSize)s to download, %(localSize)s of disk space freed") % {'downloadSize': downloadSize, 'localSize': localSize}
             else:
                 subs['sizeinfo'] = _("%(downloadSize)s to download, %(localSize)s of disk space required") % {'downloadSize': downloadSize, 'localSize': localSize}
-            
-        subs['packagesinfo'] = (', '.join(name for name in impacted_packages))
 
-        if len(package.pkg.candidate.homepage) > 0:
-            subs['homepage'] = package.pkg.candidate.homepage
-            subs['homepage_button_visibility'] = "visible"
+        if (len(installations) > 0):            
+            impacted_packages.append("<li>%s %s</li>" % (_("The following packages would be installed: "), ', '.join(installations)))
+        if (len(removals) > 0):                        
+            impacted_packages.append("<li><font color=red>%s %s</font></li>" % (_("The following packages would be removed: "), ', '.join(removals)))
+        
+        if (len(installations) > 0 or len(removals) > 0):
+            subs['packagesinfo'] = '<b>%s</b><ul>%s</ul>' % (_("Impact on packages:"), '<br>'.join(impacted_packages))
         else:
-            subs['homepage'] = ""
-            subs['homepage_button_visibility'] = "hidden"
+            subs['packagesinfo'] = ''
+
+        # if len(package.pkg.candidate.homepage) > 0:
+        #     subs['homepage'] = package.pkg.candidate.homepage
+        #     subs['homepage_button_visibility'] = "visible"
+        # else:
+        subs['homepage'] = ""
+        subs['homepage_button_visibility'] = "hidden"
         
         direction = gtk.widget_get_default_direction()
         if direction ==  gtk.TEXT_DIR_RTL:
@@ -1791,20 +1822,17 @@ class Application():
 
         if package.pkg.is_installed:
             subs['action_button_label'] = _("Remove")
-            subs['action_button_value'] = "remove"
             subs['version'] = package.pkg.installed.version
             subs['action_button_description'] = _("Installed")
             subs['iconstatus'] = "/usr/lib/linuxmint/mintInstall/data/installed.png"
         else:
             if package.pkg.name in BROKEN_PACKAGES:           
                 subs['action_button_label'] = _("Not available")
-                subs['action_button_value'] = "remove"
                 subs['version'] = package.pkg.candidate.version
                 subs['action_button_description'] = _("Please use apt-get to install this package.")
                 subs['iconstatus'] = "/usr/lib/linuxmint/mintInstall/data/available.png"
             else:
                 subs['action_button_label'] = _("Install")
-                subs['action_button_value'] = "install"
                 subs['version'] = package.pkg.candidate.version
                 subs['action_button_description'] = _("Not installed")
                 subs['iconstatus'] = "/usr/lib/linuxmint/mintInstall/data/available.png"
